plug_response_cache v0.1.1 PlugResponseCache.Stores.Ets View Source
The ETS store, which is used by default, is a GenServer that stores the
response bodies in an ETS table.
Link to this section Summary
Functions
Retrieve a response from the cache. If nothing was found, return a tuple with
:miss and a reason, e.g. {:miss, :cold} or {:miss, :expired}
Invoked when the server is started. start_link/3 or start/3 will
block until it returns
Save a response to the cache. The second argument is an expiration time in the
UTC timezone. If a response should never expire, the expiration time is
:never
Link to this section Functions
Retrieve a response from the cache. If nothing was found, return a tuple with
:miss and a reason, e.g. {:miss, :cold} or {:miss, :expired}.
Callback implementation for PlugResponseCache.Store.get/1.
Invoked when the server is started. start_link/3 or start/3 will
block until it returns.
args is the argument term (second argument) passed to start_link/3.
Returning {:ok, state} will cause start_link/3 to return
{:ok, pid} and the process to enter its loop.
Returning {:ok, state, timeout} is similar to {:ok, state}
except handle_info(:timeout, state) will be called after timeout
milliseconds if no messages are received within the timeout.
Returning {:ok, state, :hibernate} is similar to
{:ok, state} except the process is hibernated before entering the loop. See
c:handle_call/3 for more information on hibernation.
Returning :ignore will cause start_link/3 to return :ignore and the
process will exit normally without entering the loop or calling c:terminate/2.
If used when part of a supervision tree the parent supervisor will not fail
to start nor immediately try to restart the GenServer. The remainder of the
supervision tree will be (re)started and so the GenServer should not be
required by other processes. It can be started later with
Supervisor.restart_child/2 as the child specification is saved in the parent
supervisor. The main use cases for this are:
- The
GenServeris disabled by configuration but might be enabled later. - An error occurred and it will be handled by a different mechanism than the
Supervisor. Likely this approach involves callingSupervisor.restart_child/2after a delay to attempt a restart.
Returning {:stop, reason} will cause start_link/3 to return
{:error, reason} and the process to exit with reason reason without
entering the loop or calling c:terminate/2.
Callback implementation for GenServer.init/1.
Save a response to the cache. The second argument is an expiration time in the
UTC timezone. If a response should never expire, the expiration time is
:never.
Callback implementation for PlugResponseCache.Store.set/2.